[cairo-commit] goocanvas/src goocanvasitemsimple.h,1.20,1.21

Damon Chaplin commit at pdx.freedesktop.org
Thu Mar 8 08:17:40 PST 2007


Committed by: damon

Update of /cvs/cairo/goocanvas/src
In directory kemper:/tmp/cvs-serv23283/src

Modified Files:
	goocanvasitemsimple.h 
Log Message:
2007-03-08  Damon Chaplin  <damon at gnome.org>

	* src/goocanvasitemsimple.h (struct _GooCanvasItemSimpleData): use
	guints for the bitflags rather than the enum types, since that is what
	GTK+ does. Maybe enums cause a problem because of being signed ints.
	Also added cache_setting which we may use in future.
	(struct _GooCanvasItemSimple): added private pointer to allow a bit
	of expansion in future (e.g. maybe a cache).



Index: goocanvasitemsimple.h
===================================================================
RCS file: /cvs/cairo/goocanvas/src/goocanvasitemsimple.h,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -d -r1.20 -r1.21
--- goocanvasitemsimple.h	6 Mar 2007 13:21:26 -0000	1.20
+++ goocanvasitemsimple.h	8 Mar 2007 16:17:33 -0000	1.21
@@ -24,12 +24,14 @@
  *  path of the item, or %NULL.
  * @visibility_threshold: the threshold scale setting at which to show the item
  *  (if the @visibility setting is set to %VISIBLE_ABOVE_THRESHOLD).
- * @visibility: whether the item is visible, invisible, or visible above a
- *  given canvas scale setting.
- * @pointer_events: the events the item should receive.
+ * @visibility: the #GooCanvasItemVisibility setting specifying whether the
+ *  item is visible, invisible, or visible above a given canvas scale setting.
+ * @pointer_events: the #GooCanvasPointerEvents setting specifying the events
+ *  the item should receive.
  * @can_focus: if the item can take the keyboard focus.
  * @own_style: if the item has its own style, rather than using its parent's.
  * @clip_fill_rule: the fill rule used for the clip path.
  *
  * This is the data common to both the model and view classes.
  */
@@ -40,11 +42,15 @@
   cairo_matrix_t *transform;
   GArray *clip_path_commands;
   gdouble visibility_threshold;
-  GooCanvasItemVisibility visibility	: 2;
-  GooCanvasPointerEvents pointer_events : 4;
+  guint visibility			: 2;
+  guint pointer_events			: 4;
   guint can_focus                       : 1;
   guint own_style                       : 1;
   guint clip_fill_rule			: 4;
+
+  /*< private >*/
+  /* We might use this in future for a cache setting - never/always/visible. */
+  guint cache_setting			: 3;
 };
 
 
@@ -90,6 +96,10 @@
   GooCanvasBounds bounds;
   guint	need_update			: 1;
   guint need_entire_subtree_update      : 1;
+
+  /* <private> */
+  /* We might use this in future for things like a cache. */
+  gpointer private;
 };
 
 /**
@@ -24,12 +24,14 @@
  * @can_focus: if the item can take the keyboard focus.
  * @own_style: if the item has its own style, rather than using its parent's.
- * @clip_fill_rule: the fill rule used for the clip path.
+ * @clip_fill_rule: the #cairo_fill_rule_t setting specifying the fill rule
+ *  used for the clip path.
  *
  * This is the data common to both the model and view classes.



More information about the cairo-commit mailing list